@@ -42,7 +42,6 @@ class FormatGroupTest(base.BaseTestCase):
           :Default: ``<None>``
 
           this appears in the default group
-
         ''').lstrip(), results)
 
     def test_with_default_value(self):
@@ -66,7 +65,6 @@ class FormatGroupTest(base.BaseTestCase):
           :Default: ``this is the default``
 
           this appears in the default group
-
         ''').lstrip(), results)
 
     def test_with_min(self):
@@ -88,7 +86,6 @@ class FormatGroupTest(base.BaseTestCase):
           :Type: integer
           :Default: ``<None>``
           :Minimum Value: 1
-
         ''').lstrip(), results)
 
     def test_with_min_0(self):
@@ -110,7 +107,6 @@ class FormatGroupTest(base.BaseTestCase):
           :Type: integer
           :Default: ``<None>``
           :Minimum Value: 0
-
         ''').lstrip(), results)
 
     def test_with_max(self):
@@ -132,7 +128,6 @@ class FormatGroupTest(base.BaseTestCase):
           :Type: integer
           :Default: ``<None>``
           :Maximum Value: 1
-
         ''').lstrip(), results)
 
     def test_with_max_0(self):
@@ -154,7 +149,6 @@ class FormatGroupTest(base.BaseTestCase):
           :Type: integer
           :Default: ``<None>``
           :Maximum Value: 0
-
         ''').lstrip(), results)
 
     def test_with_choices(self):
@@ -176,7 +170,50 @@ class FormatGroupTest(base.BaseTestCase):
           :Type: string
           :Default: ``<None>``
           :Valid Values: a, b, c, <None>, ''
+        ''').lstrip(), results)
 
+    def test_with_choices_with_descriptions(self):
+        results = '\n'.join(list(sphinxext._format_group(
+            app=mock.Mock(),
+            namespace=None,
+            group_name=None,
+            group_obj=None,
+            opt_list=[
+                cfg.StrOpt(
+                    'opt_name',
+                    choices=[
+                        ('a', 'a is the best'),
+                        ('b', 'Actually, may-b I am better'),
+                        ('c', 'c, I am clearly the greatest'),
+                        (None, 'I am having none of this'),
+                        ('', '')]),
+            ],
+        )))
+        self.assertEqual(textwrap.dedent('''
+        .. oslo.config:group:: DEFAULT
+
+        .. oslo.config:option:: opt_name
+
+          :Type: string
+          :Default: ``<None>``
+          :Valid Values: a, b, c, <None>, ''
+
+          .. rubric:: Possible values
+
+          a
+            a is the best
+
+          b
+            Actually, may-b I am better
+
+          c
+            c, I am clearly the greatest
+
+          <None>
+            I am having none of this
+
+          ''
+            <No description provided>
         ''').lstrip(), results)
 
     def test_group_obj_without_help(self):
@@ -195,7 +232,6 @@ class FormatGroupTest(base.BaseTestCase):
 
           :Type: string
           :Default: ``<None>``
-
         ''').lstrip(), results)
 
     def test_group_obj_with_help(self):
@@ -216,7 +252,6 @@ class FormatGroupTest(base.BaseTestCase):
 
           :Type: string
           :Default: ``<None>``
-
         ''').lstrip(), results)
 
     def test_deprecated_opts_without_deprecated_group(self):
@@ -246,7 +281,6 @@ class FormatGroupTest(base.BaseTestCase):
                * Name
              - * DEFAULT
                * deprecated_name
-
         ''').lstrip(), results)
 
     def test_deprecated_opts_with_deprecated_group(self):
@@ -277,7 +311,6 @@ class FormatGroupTest(base.BaseTestCase):
                * Name
              - * deprecated_group
                * deprecated_name
-
         ''').lstrip(), results)
 
     def test_deprecated_for_removal(self):
@@ -317,7 +350,6 @@ class FormatGroupTest(base.BaseTestCase):
           :Type: integer
           :Default: ``<None>``
           :Mutable: This option can be changed without restarting.
-
         ''').lstrip(), results)
 
     def test_not_mutable(self):
@@ -338,7 +370,49 @@ class FormatGroupTest(base.BaseTestCase):
 
           :Type: integer
           :Default: ``<None>``
+        ''').lstrip(), results)
 
+    def test_advanced(self):
+        results = '\n'.join(list(sphinxext._format_group(
+            app=mock.Mock(),
+            namespace=None,
+            group_name=None,
+            group_obj=None,
+            opt_list=[
+                cfg.StrOpt('opt_name',
+                           advanced=True),
+            ],
+        )))
+        self.assertEqual(textwrap.dedent('''
+        .. oslo.config:group:: DEFAULT
+
+        .. oslo.config:option:: opt_name
+
+          :Type: string
+          :Default: ``<None>``
+          :Advanced Option: Intended for advanced users and not used
+              by the majority of users, and might have a significant
+              effect on stability and/or performance.
+        ''').lstrip(), results)
+
+    def test_not_advanced(self):
+        results = '\n'.join(list(sphinxext._format_group(
+            app=mock.Mock(),
+            namespace=None,
+            group_name=None,
+            group_obj=None,
+            opt_list=[
+                cfg.StrOpt('opt_name',
+                           advanced=False),
+            ],
+        )))
+        self.assertEqual(textwrap.dedent('''
+        .. oslo.config:group:: DEFAULT
+
+        .. oslo.config:option:: opt_name
+
+          :Type: string
+          :Default: ``<None>``
         ''').lstrip(), results)
 
 
@@ -358,14 +432,14 @@ class FormatOptionHelpTest(base.BaseTestCase):
         _format_group.assert_any_call(
             app=None,
             namespace='namespace1',
-            group_name=None,
+            group_name='DEFAULT',
             group_obj=None,
             opt_list=['opt1'],
         )
         _format_group.assert_any_call(
             app=None,
             namespace='namespace2',
-            group_name=None,
+            group_name='DEFAULT',
             group_obj=None,
             opt_list=['opt2'],
         )
@@ -384,7 +458,7 @@ class FormatOptionHelpTest(base.BaseTestCase):
         _format_group.assert_called_once_with(
             app=None,
             namespace=None,
-            group_name=None,
+            group_name='DEFAULT',
             group_obj=None,
             opt_list=['opt1', 'opt2'],
         )
